@@ -163,6 +163,8 @@ row.names.SpatialLines <- function(x) {
 #"[.SpatialLines" =  function(x, i, j, ..., drop = T) {
 setMethod("[", "SpatialLines",
 	function(x, i, j, ..., drop = TRUE) {
+	if (is(i, "Spatial"))
+		i = !is.na(over(x, geometry(i)))
 	if (is.logical(i)) {
 		if (length(i) == 1 && i)
 			i = 1:length(x@lines)
